#!/bin/bash
# packager          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage			: http://gpodder.org/
# source location	: http://download.berlios.de/gpodder/gpodder-2.1.tar.gz
# dependency        : 
# last revised      : 14.12.2009

softname='gpodder'
softversion='2.1'
packageversion='1fb'

arch='i486'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://download.berlios.de/gpodder/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# Slac-desc
cat <<EOF > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
gpodder: gPodder (GTK2 media aggregator)
gpodder:      
gpodder: gPodder is a podcast receiver/catcher written in Python utilizing
gpodder: PyGTK for its user interface.  gPodder allows the user to subscribe
gpodder: to RSS feeds for podcasts, videocasts, and other similar content
gpodder: and download media files found in those feeds.
gpodder: gPodder has system-tray notifications, support for optional iPod
gpodder: synchronization, and MP3/Ogg id3 tag editing.
gpodder:      
gpodder: 
gpodder:      
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xzvf $srcpkg
cd $src

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

make
make install DESTDIR=$dest

rm -rf $dest/usr/share/pixmaps/
   
# add 'default' files
cp -a \
   ChangeLog INSTALL COPYING README \
   $dest/usr/doc/$softname-$softversion

mv $dest/usr/share/gpodder/credits.txt $dest/usr/doc/$softname-$softversion

# strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( mv $dest/usr/share/man $dest/usr/man
  cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# SalixBuild
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 640 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -type d -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
echo -e "feedparser,gtk+2,pygtk,pygobject,pycairo,python,sqlite" > $package.dep

# .src
rm -rf $src
rm -rf $dest

# erase
echo http://people.salixos.org/fredb/xap/gpodder/build-gpodder.sh > $package.src
echo $source >>$package.src

# log
) 2>&1 | tee "$softname-$softversion-build.log"
